#!/bin/csh
#SBATCH --job-name=your_job_name
#SBATCH --account=**ask Dr. Klauda**
#SBATCH --partition=shared
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=32
#SBATCH --cpus-per-task=1
#SBATCH --mem=64G
#SBATCH --time=48:00:00
#SBATCH --no-requeue
#SBATCH --export=ALL

# This script is using 32 CPUs in 1 node with memory 64 G
# ASSUMPTION (1): input files are named   dynXX.inp   where XX is optional
#  useful for startup phase; for example, to start using dynstrt.inp,
#    dyn.csh strt
#  would be used; for production dynamics runs, simply dyn.csh
# ASSUMPTION (2): output files are named    dyn.res  dyn.trj  dyn.out
# ASSUMPTION (3): previous restart file read as  dyn.rea
#

setenv CONV_RSH ssh
unset noclobber

# Set Run Length per file
set simt = 5000000

echo Running on host `hostname`
echo Time is `date`
echo Directory is `pwd`
echo This jobs runs on the following processors:

cd $SLURM_SUBMIT_DIR
echo $SLURM_SUBMIT_DIR
pwd

#setenv PBS_NODEFILE `generate_pbs_nodefile`

# Creates nodelist
#set namd = "/homes/jbklauda/namd/NAMD_2.9_Linux-x86_64-TCP/namd2"
#set ch = "/homes/jbklauda/namd/NAMD_2.9_Linux-x86_64-TCP/charmrun"
#set NODELIST = namd2.nodelist
#set nodes = `cat $PBS_NODEFILE`
#cat $PBS_NODEFILE > nodelist
#echo group main >! $NODELIST
#foreach node ( $nodes )
#  echo host $node >> $NODELIST
#end

 @ krun = 1

if ( -e start.time) then
 @ start = `cat start.time `
else
 @ start = 0                  
endif

# Load NAMD and required modules
module load slurm/expanse/20.02.3
module load cpu/0.15.4
module load gcc/10.2.0
module load openmpi/4.0.4
module load namd/2.14

# Create a new input file
rm -f dyn.inp
cat dyn-1.inp > dyn.inp
echo "firsttimestep     $start; " >> dyn.inp
cat dyn-2.inp >> dyn.inp

set one = one
echo $one > test.file
echo $one
# Execution of the script
namd2 +p32 +setcpuaffinity dyn.inp >& dyn.out 
echo $one >> test.file
echo $one

set okay = true
# TEST FOR EXISTENCE, THEN NONZERO LENGTH OF OUTPUT FILES
if ( -e dyn.coor && -e dyn.dcd ) then
 @ tsz = `/bin/ls -s dyn.dcd | awk '{print $1}'`
 @ nrm = `grep 'WallClock' dyn.out | wc -l`
 @ nrm1 = `grep 'ERROR: ' dyn.out | wc -l`
 
echo $tsz >> test.file
echo $tsz
echo $nrm >> test.file
echo $nrm
 if ( $tsz > 0 && $nrm == 1 && $nrm1 < 1 ) then
# SUCCESSFUL RUN; COPY RESTART FILE
#  cp dyn.res dyn.rea
# DETERMINE RUN NUMBER
  if ( -e next.seqno ) then
   @ i = `cat next.seqno` 
  else
   @ i = 1
  endif
# Change the new Start Time
@ start = $start + $simt
echo $start > start.time

# ENABLE/DISABLE ANALYSIS EVERY 2ND RUN
#  if ( 0 == $i % 2 ) qsub -l nodes=1 chk.csh
# NUMBER THE OUTPUT FILES; CHANGE EXTENSIONS TO SUIT APPLICATION
  foreach fil ( out coor xsc xst vel dcd )
   mv dyn.$fil dyn$i.$fil
  end
  cp dyn$i.xsc dyn.xsc
  cp dyn$i.coor dyn.coor
  cp dyn$i.vel dyn.vel
  gzip dyn$i.out dyn$i.coor dyn$i.xsc dyn$i.vel dyn$i.xst
# CONDITIONAL END CHECK
  if ( -e last.seqno ) then
    @ l = `cat last.seqno`
    if ( $i == $l ) then
      @ i += 1
      echo $i > next.seqno 
      exit
    endif
  endif

# SUBMIT THE NEXT JOB
#  rm ~/namd.$PBS_JOBID
  sleep 5m
  @ i += 1
  echo $i > next.seqno
  ./dyn.scr
  exit
else
# FILE DOESN'T EXIST
 set okay = false
endif
# FILE DOESN'T EXIST
 set okay = false
endif

# TEST FOR CHARMM RUN FAILED; CREATE .ERR FILE WITH TIMESTAMP
if ( $okay == false ) then
 set ts = `date +%m%d.%H%M`
 mv dyn.out dyn.err.$ts
 exit(201)
endif


